summaryrefslogtreecommitdiff
path: root/poezio/core/handlers.py
diff options
context:
space:
mode:
Diffstat (limited to 'poezio/core/handlers.py')
-rw-r--r--poezio/core/handlers.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/poezio/core/handlers.py b/poezio/core/handlers.py
index 9cdfb59a..95fa6a48 100644
--- a/poezio/core/handlers.py
+++ b/poezio/core/handlers.py
@@ -561,7 +561,7 @@ class HandlerCore:
'Mood')
else:
self.core.information(
contact.bare_jid + ' stopped having his/her mood.', 'Mood')
def on_activity_event(self, message):
"""
@@ -606,7 +606,7 @@ class HandlerCore:
contact.activity, 'Activity')
else:
self.core.information(
contact.bare_jid + ' stopped doing his/her activity.',
'Activity')
def on_tune_event(self, message):
@@ -1015,7 +1015,7 @@ class HandlerCore:
contact.pending_out = False
else:
self.core.information(
- '%s does not want you to receive his/her/its status anymore.' %
+ '%s does not want you to receive their/its status anymore.' %
jid, 'Roster')
self.core.tabs.first().state = 'highlight'
if isinstance(self.core.tabs.current_tab, tabs.RosterInfoTab):
@@ -561,7 +561,7 @@ class HandlerCore:
else:
self.core.information(
- contact.bare_jid + ' stopped having his/her mood.', 'Mood')
+ contact.bare_jid + ' stopped having their mood.', 'Mood')
def on_activity_event(self, message):
"""
@@ -606,7 +606,7 @@ class HandlerCore:
else:
self.core.information(
- contact.bare_jid + ' stopped doing his/her activity.',
+ contact.bare_jid + ' stopped doing their activity.',
'Activity')
def on_tune_event(self, message):